/**
 * Class holding a field reference ( table and column name )
 *
 * @export
 * @class FieldReference
 */
export declare class FieldReference {
    /**
     * A table name
     *
     * @type {string}
     */
    tableName: string;
    /**
     * A column name
     *
     * @type {string}
     */
    colName: string;
    /**
     * Creates an instance of FieldReference.
     *
     * @param {string} tableName
     * @param {string} colName
     */
    constructor(tableName: string, colName: string);
}
/**
 * Class holding a field definition
 *
 * @export
 * @class Field
 */
export declare class Field {
    /**
     * The name of the column
     *
     * @type {string}
     */
    private _name;
    name: string;
    /**
     * The property key mapped to this field
     *
     * @type {(string|symbol)}
     */
    propertyKey: string | symbol;
    /**
     * The property type mapped to this field
     *
     * @type {string}
     */
    propertyType?: string;
    /**
     * The type of the table column
     *
     * @type {string}
     */
    dbtype: string;
    /**
     * Flag if this field is part of the primary key
     *
     * @type {boolean}
     */
    isIdentity: boolean;
    /**
     * Map of all the foreign key constraints this field participates
     *
     * @type {Map<string, FieldReference>}
     */
    foreignKeys: Map<string, FieldReference>;
    private _hostParameterName;
    readonly hostParameterName: string;
    /**
     * Creates an instance of Field.
     *
     */
    constructor(key: string | symbol);
    hasForeignKeyConstraint(constraintName: string): boolean;
    /**
     * Set this field to participate in a foreign key constraint
     *
     * @param {string} constraintName - The constraint name
     * @param {FieldReference} foreignTableField - The referenced table and column
     */
    setForeignKeyField(constraintName: string, foreignTableField: FieldReference): void;
    /**
     * Test if this field is part of the given foreign key constraint
     *
     * @param {string} constraintName
     * @returns {boolean}
     */
    hasForeignKeyField(constraintName: string): boolean;
    /**
     * Get the field reference for the given foreign key constraint
     *
     * @param {string} constraintName
     * @returns {FieldReference}
     */
    getForeignKeyField(constraintName: string): FieldReference;
}
