"use strict";
/**
 * Class holding a field reference ( table and column name )
 *
 * @export
 * @class FieldReference
 */
class FieldReference {
    /**
     * Creates an instance of FieldReference.
     *
     * @param {string} tableName
     * @param {string} colName
     */
    constructor(tableName, colName) {
        this.tableName = tableName;
        this.colName = colName;
    }
}
exports.FieldReference = FieldReference;
/**
 * Class holding a field definition
 *
 * @export
 * @class Field
 */
class Field {
    /**
     * Creates an instance of Field.
     *
     */
    constructor(key) {
        this.propertyKey = key;
        this.propertyType = undefined;
        this.isIdentity = false;
        this.dbtype = 'TEXT';
        this.foreignKeys = new Map();
    }
    get name() {
        return this._name;
    }
    set name(value) {
        this._name = value;
        this._hostParameterName = ':' + value;
    }
    get hostParameterName() {
        return this._hostParameterName;
    }
    hasForeignKeyConstraint(constraintName) {
        return this.foreignKeys.has(constraintName);
    }
    /**
     * Set this field to participate in a foreign key constraint
     *
     * @param {string} constraintName - The constraint name
     * @param {FieldReference} foreignTableField - The referenced table and column
     */
    setForeignKeyField(constraintName, foreignTableField) {
        this.foreignKeys.set(constraintName, foreignTableField);
    }
    /**
     * Test if this field is part of the given foreign key constraint
     *
     * @param {string} constraintName
     * @returns {boolean}
     */
    hasForeignKeyField(constraintName) {
        return this.foreignKeys.has(constraintName);
    }
    /**
     * Get the field reference for the given foreign key constraint
     *
     * @param {string} constraintName
     * @returns {FieldReference}
     */
    getForeignKeyField(constraintName) {
        return this.foreignKeys.get(constraintName);
    }
}
exports.Field = Field;
//# sourceMappingURL=Field.js.map