import { Table } from './Table';
import { SqlDatabase } from './SqlDatabase';
/**
 * A singleton holding the database schema definitions
 *
 * @export
 * @class Schema
 */
export declare class Schema {
    /**
     * The one and only Schema instance
     *
     * @static
     * @type {Schema}
     */
    static schema: Schema;
    private mapNameToTable;
    /**
     * Creates an instance of Schema.
     *
     */
    constructor();
    /**
     * get a table definition
     *
     * @param {string} name - The name of the table
     * @returns {Table}
     */
    getTable(name: string): Table;
    /**
     * add a table definition
     *
     * @param {string} name - The name of the table
     * @param {Table} table
     * @returns {Table}
     */
    addTable(table: Table): Table;
    /**
     * create a table in the database
     *
     * @param {SqlDatabase} sqldb
     * @param {string} name - The name of the table
     * @returns {Promise<void>}
     */
    createTable(sqldb: SqlDatabase, name: string): Promise<void>;
    /**
     * drop a table from the database
     *
     * @param {SqlDatabase} sqldb
     * @param {string} name - The name of the table
     * @returns {Promise<void>}
     */
    dropTable(sqldb: SqlDatabase, name: string): Promise<void>;
    /**
     * add a column/field to a database table
     *
     * @param {SqlDatabase} sqldb
     * @param {string} tableName
     * @param {string} colName
     * @returns {Promise<void>}
     */
    alterTableAddColumn(sqldb: SqlDatabase, tableName: string, colName: string): Promise<void>;
}
/**
 * get the Schema singleton
 *
 * @export
 * @returns {Schema}
 */
export declare function schema(): Schema;
